# R code to replicate 
# Gartzke & Gleditsch AJSP 2004
#
# Please contact Kristian Skrede Gleditsch
# 	kgleditsch@ucsd.edu with any questions
#	on this file or the replication data

# Replace PATH with your locadirectory

PATH <- "c:/work/work8/newioallies/"

infile <- paste(PATH,"egksg04rep.asc",sep="")


# Read data from ASCII file
egksg04rep.data <- read.table(infile,sep="\t",header=T)

# This sample is limited to defense pacts alliance dyads 
#
# Variables:
#
# assist: 1 if state fought on side of ally in war
#	(0 if not participant, -1 if on other side)
#
# demb: Polity score of ally, democracy if 6+
#
# otherally: 1 if state allied with other side
#
# contig: 1 if allies are contiguous
#
# cinca/cincb: Cinc scores of country at war and ally

# This replicates Table 1 in paper
#
summary(glm((assist==1) ~ I(demb>=6 & !is.na(demb)) + 
	+ otherally
	+ contig + cinca + cincb,
	,na.action=na.omit,data=egksg04rep.data,
	family=binomial(link=logit)))

# (Results in Table 2 were estimated for us by Ashely Leeds 
# 	on the ATOP data. These are not yet publically released
#	and we are not able to post replication data)
#

# (See separate Stata file for the results in Table 3)

